@@ -137,7 +137,7 @@ func TestFlowWithConditionPositive(t *testing.T) {
 	err = Template.Executer.Compile()
 	require.Nil(t, err, "could not compile template")
 
-	input := contextargs.NewWithInput(context.Background(), "blog.projectdiscovery.io")
+	input := contextargs.NewWithInput(context.Background(), "cloud.projectdiscovery.io")
 	ctx := scan.NewScanContext(context.Background(), input)
 	// positive match . expect results also verify that both dns() and http() were executed
 	gotresults, err := Template.Executer.Execute(ctx)
@@ -150,8 +150,7 @@ func TestFlowWithNoMatchers(t *testing.T) {
 	// when using conditional flow with no matchers at all
 	// we implicitly assume that request was successful and internally changed the result to true (for scope of condition only)
 
-	// testcase-1 : no matchers but contains extractor
-	Template, err := templates.Parse("testcases/condition-flow-extractors.yaml", nil, executerOpts)
+	Template, err := templates.Parse("testcases/condition-flow-no-operators.yaml", nil, executerOpts)
 	require.Nil(t, err, "could not parse template")
 
 	require.True(t, Template.Flow != "", "not a flow template") // this is classifer if template is flow or not
@@ -159,27 +158,27 @@ func TestFlowWithNoMatchers(t *testing.T) {
 	err = Template.Executer.Compile()
 	require.Nil(t, err, "could not compile template")
 
-	input := contextargs.NewWithInput(context.Background(), "blog.projectdiscovery.io")
-	ctx := scan.NewScanContext(context.Background(), input)
-	// positive match . expect results also verify that both dns() and http() were executed
-	gotresults, err := Template.Executer.Execute(ctx)
-	require.Nil(t, err, "could not execute template")
-	require.True(t, gotresults)
-
-	// testcase-2 : no matchers and no extractors
-	Template, err = templates.Parse("testcases/condition-flow-no-operators.yaml", nil, executerOpts)
-	require.Nil(t, err, "could not parse template")
-
-	require.True(t, Template.Flow != "", "not a flow template") // this is classifer if template is flow or not
-
-	err = Template.Executer.Compile()
-	require.Nil(t, err, "could not compile template")
-
-	anotherInput := contextargs.NewWithInput(context.Background(), "blog.projectdiscovery.io")
+	anotherInput := contextargs.NewWithInput(context.Background(), "cloud.projectdiscovery.io")
 	anotherCtx := scan.NewScanContext(context.Background(), anotherInput)
 	// positive match . expect results also verify that both dns() and http() were executed
-	gotresults, err = Template.Executer.Execute(anotherCtx)
+	gotresults, err := Template.Executer.Execute(anotherCtx)
 	require.Nil(t, err, "could not execute template")
 	require.True(t, gotresults)
 
+	t.Run("Contains Extractor", func(t *testing.T) {
+		Template, err := templates.Parse("testcases/condition-flow-extractors.yaml", nil, executerOpts)
+		require.Nil(t, err, "could not parse template")
+
+		require.True(t, Template.Flow != "", "not a flow template") // this is classifer if template is flow or not
+
+		err = Template.Executer.Compile()
+		require.Nil(t, err, "could not compile template")
+
+		input := contextargs.NewWithInput(context.Background(), "scanme.sh")
+		ctx := scan.NewScanContext(context.Background(), input)
+		// positive match . expect results also verify that both dns() and http() were executed
+		gotresults, err := Template.Executer.Execute(ctx)
+		require.Nil(t, err, "could not execute template")
+		require.True(t, gotresults)
+	})
 }
